@@ -16,6 +16,7 @@ import sys
 from typing import IO, Any, Dict, List, Type, Union, overload
 
 from botocore.client import ClientMeta
+from botocore.response import StreamingBody
 
 from .literals import EnhancedMonitoringType
 from .paginator import (
@@ -96,7 +97,7 @@ class Exceptions:
 
 class KafkaClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/kafka.html#Kafka.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kafka.html#Kafka.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html)
     """
 
@@ -107,7 +108,7 @@ class KafkaClient:
         self, *, ClusterArn: str, SecretArnList: List[str]
     ) -> BatchAssociateScramSecretResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/kafka.html#Kafka.Client.batch_associate_scram_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kafka.html#Kafka.Client.batch_associate_scram_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#batch_associate_scram_secret)
         """
 
@@ -115,13 +116,13 @@ class KafkaClient:
         self, *, ClusterArn: str, SecretArnList: List[str]
     ) -> BatchDisassociateScramSecretResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/kafka.html#Kafka.Client.batch_disassociate_scram_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kafka.html#Kafka.Client.batch_disassociate_scram_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#batch_disassociate_scram_secret)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/kafka.html#Kafka.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kafka.html#Kafka.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#can_paginate)
         """
 
@@ -141,7 +142,7 @@ class KafkaClient:
         Tags: Dict[str, str] = None
     ) -> CreateClusterResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/kafka.html#Kafka.Client.create_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kafka.html#Kafka.Client.create_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#create_cluster)
         """
 
@@ -149,12 +150,12 @@ class KafkaClient:
         self,
         *,
         Name: str,
-        ServerProperties: Union[bytes, IO[bytes]],
+        ServerProperties: Union[bytes, IO[bytes], StreamingBody],
         Description: str = None,
         KafkaVersions: List[str] = None
     ) -> CreateConfigurationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/kafka.html#Kafka.Client.create_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kafka.html#Kafka.Client.create_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#create_configuration)
         """
 
@@ -162,19 +163,19 @@ class KafkaClient:
         self, *, ClusterArn: str, CurrentVersion: str = None
     ) -> DeleteClusterResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/kafka.html#Kafka.Client.delete_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kafka.html#Kafka.Client.delete_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#delete_cluster)
         """
 
     def delete_configuration(self, *, Arn: str) -> DeleteConfigurationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/kafka.html#Kafka.Client.delete_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kafka.html#Kafka.Client.delete_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#delete_configuration)
         """
 
     def describe_cluster(self, *, ClusterArn: str) -> DescribeClusterResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/kafka.html#Kafka.Client.describe_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kafka.html#Kafka.Client.describe_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#describe_cluster)
         """
 
@@ -182,13 +183,13 @@ class KafkaClient:
         self, *, ClusterOperationArn: str
     ) -> DescribeClusterOperationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/kafka.html#Kafka.Client.describe_cluster_operation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kafka.html#Kafka.Client.describe_cluster_operation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#describe_cluster_operation)
         """
 
     def describe_configuration(self, *, Arn: str) -> DescribeConfigurationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/kafka.html#Kafka.Client.describe_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kafka.html#Kafka.Client.describe_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#describe_configuration)
         """
 
@@ -196,7 +197,7 @@ class KafkaClient:
         self, *, Arn: str, Revision: int
     ) -> DescribeConfigurationRevisionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/kafka.html#Kafka.Client.describe_configuration_revision)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kafka.html#Kafka.Client.describe_configuration_revision)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#describe_configuration_revision)
         """
 
@@ -208,13 +209,13 @@ class KafkaClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/kafka.html#Kafka.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kafka.html#Kafka.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#generate_presigned_url)
         """
 
     def get_bootstrap_brokers(self, *, ClusterArn: str) -> GetBootstrapBrokersResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/kafka.html#Kafka.Client.get_bootstrap_brokers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kafka.html#Kafka.Client.get_bootstrap_brokers)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#get_bootstrap_brokers)
         """
 
@@ -222,7 +223,7 @@ class KafkaClient:
         self, *, ClusterArn: str = None
     ) -> GetCompatibleKafkaVersionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/kafka.html#Kafka.Client.get_compatible_kafka_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kafka.html#Kafka.Client.get_compatible_kafka_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#get_compatible_kafka_versions)
         """
 
@@ -230,7 +231,7 @@ class KafkaClient:
         self, *, ClusterArn: str, MaxResults: int = None, NextToken: str = None
     ) -> ListClusterOperationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/kafka.html#Kafka.Client.list_cluster_operations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kafka.html#Kafka.Client.list_cluster_operations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#list_cluster_operations)
         """
 
@@ -238,7 +239,7 @@ class KafkaClient:
         self, *, ClusterNameFilter: str = None, MaxResults: int = None, NextToken: str = None
     ) -> ListClustersResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/kafka.html#Kafka.Client.list_clusters)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kafka.html#Kafka.Client.list_clusters)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#list_clusters)
         """
 
@@ -246,7 +247,7 @@ class KafkaClient:
         self, *, Arn: str, MaxResults: int = None, NextToken: str = None
     ) -> ListConfigurationRevisionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/kafka.html#Kafka.Client.list_configuration_revisions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kafka.html#Kafka.Client.list_configuration_revisions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#list_configuration_revisions)
         """
 
@@ -254,7 +255,7 @@ class KafkaClient:
         self, *, MaxResults: int = None, NextToken: str = None
     ) -> ListConfigurationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/kafka.html#Kafka.Client.list_configurations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kafka.html#Kafka.Client.list_configurations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#list_configurations)
         """
 
@@ -262,7 +263,7 @@ class KafkaClient:
         self, *, MaxResults: int = None, NextToken: str = None
     ) -> ListKafkaVersionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/kafka.html#Kafka.Client.list_kafka_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kafka.html#Kafka.Client.list_kafka_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#list_kafka_versions)
         """
 
@@ -270,7 +271,7 @@ class KafkaClient:
         self, *, ClusterArn: str, MaxResults: int = None, NextToken: str = None
     ) -> ListNodesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/kafka.html#Kafka.Client.list_nodes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kafka.html#Kafka.Client.list_nodes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#list_nodes)
         """
 
@@ -278,13 +279,13 @@ class KafkaClient:
         self, *, ClusterArn: str, MaxResults: int = None, NextToken: str = None
     ) -> ListScramSecretsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/kafka.html#Kafka.Client.list_scram_secrets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kafka.html#Kafka.Client.list_scram_secrets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#list_scram_secrets)
         """
 
     def list_tags_for_resource(self, *, ResourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/kafka.html#Kafka.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kafka.html#Kafka.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#list_tags_for_resource)
         """
 
@@ -292,19 +293,19 @@ class KafkaClient:
         self, *, BrokerIds: List[str], ClusterArn: str
     ) -> RebootBrokerResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/kafka.html#Kafka.Client.reboot_broker)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kafka.html#Kafka.Client.reboot_broker)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#reboot_broker)
         """
 
     def tag_resource(self, *, ResourceArn: str, Tags: Dict[str, str]) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/kafka.html#Kafka.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kafka.html#Kafka.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#tag_resource)
         """
 
     def untag_resource(self, *, ResourceArn: str, TagKeys: List[str]) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/kafka.html#Kafka.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kafka.html#Kafka.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#untag_resource)
         """
 
@@ -312,7 +313,7 @@ class KafkaClient:
         self, *, ClusterArn: str, CurrentVersion: str, TargetNumberOfBrokerNodes: int
     ) -> UpdateBrokerCountResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/kafka.html#Kafka.Client.update_broker_count)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kafka.html#Kafka.Client.update_broker_count)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#update_broker_count)
         """
 
@@ -324,7 +325,7 @@ class KafkaClient:
         TargetBrokerEBSVolumeInfo: List["BrokerEBSVolumeInfoTypeDef"]
     ) -> UpdateBrokerStorageResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/kafka.html#Kafka.Client.update_broker_storage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kafka.html#Kafka.Client.update_broker_storage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#update_broker_storage)
         """
 
@@ -332,7 +333,7 @@ class KafkaClient:
         self, *, ClusterArn: str, CurrentVersion: str, TargetInstanceType: str
     ) -> UpdateBrokerTypeResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/kafka.html#Kafka.Client.update_broker_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kafka.html#Kafka.Client.update_broker_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#update_broker_type)
         """
 
@@ -340,7 +341,7 @@ class KafkaClient:
         self, *, ClusterArn: str, ConfigurationInfo: "ConfigurationInfoTypeDef", CurrentVersion: str
     ) -> UpdateClusterConfigurationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/kafka.html#Kafka.Client.update_cluster_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kafka.html#Kafka.Client.update_cluster_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#update_cluster_configuration)
         """
 
@@ -353,15 +354,19 @@ class KafkaClient:
         ConfigurationInfo: "ConfigurationInfoTypeDef" = None
     ) -> UpdateClusterKafkaVersionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/kafka.html#Kafka.Client.update_cluster_kafka_version)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kafka.html#Kafka.Client.update_cluster_kafka_version)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#update_cluster_kafka_version)
         """
 
     def update_configuration(
-        self, *, Arn: str, ServerProperties: Union[bytes, IO[bytes]], Description: str = None
+        self,
+        *,
+        Arn: str,
+        ServerProperties: Union[bytes, IO[bytes], StreamingBody],
+        Description: str = None
     ) -> UpdateConfigurationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/kafka.html#Kafka.Client.update_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kafka.html#Kafka.Client.update_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#update_configuration)
         """
 
@@ -375,7 +380,7 @@ class KafkaClient:
         LoggingInfo: "LoggingInfoTypeDef" = None
     ) -> UpdateMonitoringResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/kafka.html#Kafka.Client.update_monitoring)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kafka.html#Kafka.Client.update_monitoring)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#update_monitoring)
         """
 
@@ -384,13 +389,13 @@ class KafkaClient:
         self, operation_name: Literal["list_cluster_operations"]
     ) -> ListClusterOperationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/kafka.html#Kafka.Paginator.ListClusterOperations)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listclusteroperationspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kafka.html#Kafka.Paginator.ListClusterOperations)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listclusteroperationspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_clusters"]) -> ListClustersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/kafka.html#Kafka.Paginator.ListClusters)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listclusterspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kafka.html#Kafka.Paginator.ListClusters)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listclusterspaginator)
         """
 
     @overload
@@ -398,7 +403,7 @@ class KafkaClient:
         self, operation_name: Literal["list_configuration_revisions"]
     ) -> ListConfigurationRevisionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/kafka.html#Kafka.Paginator.ListConfigurationRevisions)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listconfigurationrevisionspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kafka.html#Kafka.Paginator.ListConfigurationRevisions)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listconfigurationrevisionspaginator)
         """
 
     @overload
@@ -406,7 +411,7 @@ class KafkaClient:
         self, operation_name: Literal["list_configurations"]
     ) -> ListConfigurationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/kafka.html#Kafka.Paginator.ListConfigurations)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listconfigurationspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kafka.html#Kafka.Paginator.ListConfigurations)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listconfigurationspaginator)
         """
 
     @overload
@@ -414,13 +419,13 @@ class KafkaClient:
         self, operation_name: Literal["list_kafka_versions"]
     ) -> ListKafkaVersionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/kafka.html#Kafka.Paginator.ListKafkaVersions)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listkafkaversionspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kafka.html#Kafka.Paginator.ListKafkaVersions)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listkafkaversionspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_nodes"]) -> ListNodesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/kafka.html#Kafka.Paginator.ListNodes)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listnodespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kafka.html#Kafka.Paginator.ListNodes)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listnodespaginator)
         """
 
     @overload
@@ -428,5 +433,5 @@ class KafkaClient:
         self, operation_name: Literal["list_scram_secrets"]
     ) -> ListScramSecretsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/kafka.html#Kafka.Paginator.ListScramSecrets)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listscramsecretspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kafka.html#Kafka.Paginator.ListScramSecrets)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listscramsecretspaginator)
         """
