@@ -15,6 +15,8 @@ import sys
 from datetime import datetime
 from typing import IO, Dict, List, Union
 
+from botocore.response import StreamingBody
+
 from .literals import (
     ClientBrokerType,
     ClusterStateType,
@@ -407,7 +409,7 @@ DescribeConfigurationRevisionResponseTypeDef = TypedDict(
         "CreationTime": datetime,
         "Description": str,
         "Revision": int,
-        "ServerProperties": Union[bytes, IO[bytes]],
+        "ServerProperties": Union[bytes, IO[bytes], StreamingBody],
     },
     total=False,
 )
